@@ -331,7 +331,7 @@ class BaseExperiment:
         del self.data_module
         self.data_module = None
         data_module = None
-        if isinstance(self.model, ConvNet):
+        if isinstance(self.model, ConvNet) or isinstance(self.model, SegNet):
             if len(self.X.shape) > 2:
                 data_module = initialize_datamodule(
                     batch_size=self.model.hparams['batch_size'], 
