@@ -1,11 +1,14 @@
 from astrape.utilities.dataloader_lightning import DataModule
 from astrape.utilities.utils_lightning import initialize_datamodule, initialize_model
 from astrape.utilities.utils_lightning import set_default_parameters
-from astrape.utilities.utils import rearrange_dims
+from astrape.utilities.utils import rearrange_dims, SegCELossMetrics, CELossMetrics, BCELossMetrics
 __all__ = [
     "DataModule", 
     "initialize_datamodule", 
     "initialize_model", 
     "set_default_parameters",
-    "rearrange_dims"
+    "rearrange_dims",
+    "SegCELossMetrics",
+    "CELossMetrics",
+    "BCELossMetrics"
     ]
